<div class="flex flex-row gap-5 
{% if main_element %} h-screen p-4{% else %}{% if grow %} h-full{% endif %}{% endif %}">
    {% for child, span in children_and_span %}
    <div class="flex-{{ span }} relative">
        {{ child|safe }}
    </div>
    {% endfor %}
</div>